const Env = use('Env')
const Helper = require('gbox-helper')
const Gbox = require('gbox-apis')({
    host: Env.get('DB_CRM_HOST'),
    port: Env.get('DB_CRM_PORT'),
    user: Env.get('DB_CRM_USER'),
    password: Env.get('DB_CRM_PASSWORD'),
    database: Env.get('DB_CRM_DATABASE'),
})

const Config = use('Config')
const Redis = require('ioredis')
const redis = new Redis(Config.get('envConfig.datastores.cache'))

class GaussBoxContactService {
    constructor({crmData}) {
        this.crmData = crmData
    }
    
    static async getApiData(apiSlug) {
        let apiData = []
        try{
            apiData = await redis.get('apiData')
            apiData = JSON.parse(apiData)
        } catch (e) {
            console.error('Failed at getting api data through redis')
            console.error(e)
        }
        
        if(!apiData || !apiData.length) {
            let fetchedApiData = await Gbox.getData();
            Object.assign(apiData, fetchedApiData)
        }
        
        return apiData.find(api => api.slug === apiSlug)
    }
    
    async get(apiSlug, endpoint) {
        let api = await GaussBoxContactService.getApiData(apiSlug)
        let url = `${api.url}${endpoint}`
        return await Helper.gbox.internalRedirect(
            this.crmData,
            Env.get('GAUSSBOX_SECRETE'),
            url,
            'GET'
        )
    }
    
    async send(apiSlug, endpoint, method, customData) {
        //remove request body
        let dataCopy = {}
        Object.assign(dataCopy, this.crmData)
        delete dataCopy.data
        if(customData) dataCopy.data = customData
        
        let api = await GaussBoxContactService.getApiData(apiSlug);
        let url = `${api.url}${endpoint}`
        return await Helper.gbox.internalRedirect(
            dataCopy,
            Env.get('GAUSSBOX_SECRETE'),
            url,
            method
        )
    }
}

module.exports = GaussBoxContactService
