const BaseScrapper = use('GBoxScrappers/Base')
const Database = use('Database')

class LeadActivity extends BaseScrapper {
    constructor(...params) {
        super(...params)
        this.tableName = 'medicalLead_activity'
        this.mediaTableName = 'medicalLead_activity_media'
        this.participantsTableName = ''
        this.columnName = 'activity'
        this.route = `/v1/medicalLead/checkUserPermissions?activity=${this.id}`
        this.nameField = 'subject'
        this.api = 'medicalLead-api'
    }
    
    async getEntityClassName() {
        return 'activity'
    }
    
    async getEntityName() {
        const entity = await this.getEntity()
        return (entity && entity.subject) || (entity && entity.subtype) || (entity && entity.type) || ''
    }
    
    async getUsersOnEntity() {
        const entity = await this.getEntity()
        if(!entity) return []
        const [leadPerson] = entity.insurancePerson && await Database.table('medicalLead_person').where('id', entity.insurancePerson) // at the time of writing, key was called insurancePerson, change if it changes to leadPerson
        const [contact, owner] = await Promise.all([
            leadPerson && leadPerson.convertedTo && await Database.table('usr_users').where('id', leadPerson.convertedTo),
            entity.owner && Database.table('usr_users').where('id', entity.owner),
        ])
        return [contact && contact[0], owner && owner[0]].filter(tr => tr)
    }
}

module.exports= LeadActivity
